@@ -4,21 +4,21 @@ use strict ;
 use warnings;
 use bytes;
 
-use IO::Compress::Base::Common 2.101 qw(:Status );
+use IO::Compress::Base::Common 2.217 qw(:Status );
 
-use IO::Uncompress::Base 2.101 ;
-use IO::Uncompress::Adapter::Bunzip2 2.101 ;
+use IO::Uncompress::Base 2.217 ;
+use IO::Uncompress::Adapter::Bunzip2 2.217 ;
 
 require Exporter ;
 our ($VERSION, @ISA, @EXPORT_OK, %EXPORT_TAGS, $Bunzip2Error);
 
-$VERSION = '2.101';
+$VERSION = '2.217';
 $Bunzip2Error = '';
 
 @ISA    = qw(IO::Uncompress::Base Exporter);
 @EXPORT_OK = qw( $Bunzip2Error bunzip2 ) ;
 #%EXPORT_TAGS = %IO::Uncompress::Base::EXPORT_TAGS ;
-push @{ $EXPORT_TAGS{all} }, @EXPORT_OK ;
+$EXPORT_TAGS{all} = [ defined $EXPORT_TAGS{all} ? @{ $EXPORT_TAGS{all} } : (), @EXPORT_OK ] ;
 #Exporter::export_ok_tags('all');
 
 
@@ -130,7 +130,9 @@ sub chkTrailer
 sub isBzip2Magic
 {
     my $buffer = shift ;
-    return $buffer =~ /^BZh\d$/;
+
+                  # ASCII:  B   Z   h    0    9
+    return $buffer =~ qr/^\x42\x5A\x68[\x30-\x39]$/;
 }
 
 1 ;
@@ -418,7 +420,7 @@ C<InputLength> option.
 
 =back
 
-=head2 Examples
+=head2 OneShot Examples
 
 To read the contents of the file C<file1.txt.bz2> and write the
 uncompressed data to the file C<file1.txt>.
@@ -478,6 +480,9 @@ The format of the constructor for IO::Uncompress::Bunzip2 is shown below
     my $z = IO::Uncompress::Bunzip2->new( $input [OPTS] )
         or die "IO::Uncompress::Bunzip2 failed: $Bunzip2Error\n";
 
+The constructor takes one mandatory parameter, C<$input>, defined below, and
+zero or more C<OPTS>, defined in L<Constructor Options>.
+
 Returns an C<IO::Uncompress::Bunzip2> object on success and undef on failure.
 The variable C<$Bunzip2Error> will contain an error message on failure.
 
@@ -490,6 +495,20 @@ use either of these forms
     $line = $z->getline();
     $line = <$z>;
 
+Below is a simple exaple of using the OO interface to read the compressed file
+C<myfile.bz2> and write its contents to stdout.
+
+    my $filename = "myfile.bz2";
+    my $z = IO::Uncompress::Bunzip2->new($filename)
+        or die "IO::Uncompress::Bunzip2 failed: $Bunzip2Error\n";
+
+    while (<$z>) {
+        print $_;
+    }
+    $z->close();
+
+See L</EXAMPLES> for further examples
+
 The mandatory parameter C<$input> is used to determine the source of the
 compressed data. This parameter can take one of three forms.
 
@@ -615,10 +634,6 @@ Default is 0.
 
 =back
 
-=head2 Examples
-
-TODO
-
 =head1 Methods
 
 =head2 read
@@ -907,7 +922,7 @@ See the Changes file.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2005-2021 Paul Marquess. All rights reserved.
+Copyright (c) 2005-2026 Paul Marquess. All rights reserved.
 
 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.
